from setuptools import setup

setup(
    name='EMenus',
    version='0.0.71',
    description='a simpler way to create menus!',
    license='MIT',
    packages=['EMenus'],
    author='Artur Zaytsev',
    author_email='huskielunar@gmail.com',
    keywords=['menus','easier','Artur Zaytsev','EMenus'],
    url='https://github.com/HUSKI3/EMenus'
)